@@ -21,7 +21,7 @@
 #include <goffice/goffice-config.h>
 #include "go-data-simple.h"
 #include "go-data-impl.h"
-#include <goffice/utils/format.h>
+#include <goffice/utils/go-format.h>
 #include <goffice/utils/go-math.h>
 
 #include <gsf/gsf-impl-utils.h>
