@@ -15,14 +15,16 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
 #include <goffice/goffice-config.h>
 #include "gog-line.h"
 #include "gog-1.5d.h"
+#include <goffice/graph/gog-series-lines.h>
 #include <goffice/graph/gog-view.h>
+#include <goffice/graph/gog-chart.h>
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/graph/gog-style.h>
 #include <goffice/graph/gog-axis.h>
@@ -195,6 +197,7 @@ static void
 gog_line_plot_init (GogLinePlot *plot)
 {
 	plot->default_style_has_markers = TRUE;
+	GOG_PLOT1_5D (plot)->support_drop_lines = TRUE;
 }
 
 GSF_DYNAMIC_CLASS (GogLinePlot, gog_line_plot,
@@ -228,6 +231,7 @@ static void
 gog_area_plot_init (GogPlot *plot)
 {
 	plot->render_before_axes = TRUE;
+	GOG_PLOT1_5D (plot)->support_drop_lines = TRUE;
 }
 
 GSF_DYNAMIC_CLASS (GogAreaPlot, gog_area_plot,
@@ -252,6 +256,9 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 	GogPlot1_5d const *model = GOG_PLOT1_5D (view->model);
 	GogPlot1_5dType const type = model->type;
 	GogSeries1_5d const *series;
+	GogChart *chart = GOG_CHART (view->model->parent);
+	GogChartMap *chart_map;
+	GogViewAllocation const *area;
 	unsigned i, j, k;
 	unsigned num_elements = model->num_elements;
 	unsigned num_series = model->num_series;
@@ -262,10 +269,12 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 	ErrorBarData **error_data;
 	GogStyle **styles;
 	unsigned *lengths;
-	ArtVpath **path;
+	ArtVpath **path, **drop_paths;
 	GogErrorBar **errors;
+	GogObjectRole const *role = NULL;
+	GogSeriesLines **lines;
 
-	double y_zero;
+	double y_zero, drop_lines_y_zero;
 	double abs_sum, sum, value;
 	gboolean is_null, is_area_plot;
 
@@ -276,27 +285,34 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 	if (num_elements <= 0 || num_series <= 0)
 		return;
 
-	x_map = gog_axis_map_new (model->base.axis[0], 
-				  view->allocation.x, view->allocation.w);
-	y_map = gog_axis_map_new (model->base.axis[1], 
-				  view->allocation.y + view->allocation.h, 
-				  -view->allocation.h);
-	
-	if (!(gog_axis_map_is_valid (x_map) &&
-	      gog_axis_map_is_valid (y_map))) {
-		gog_axis_map_free (x_map);
-		gog_axis_map_free (y_map);
+	area = gog_chart_view_get_plot_area (view->parent);
+	chart_map = gog_chart_map_new (chart, area, 
+				       GOG_PLOT (model)->axis[GOG_AXIS_X], 
+				       GOG_PLOT (model)->axis[GOG_AXIS_Y],
+				       NULL, FALSE);
+	if (!gog_chart_map_is_valid (chart_map)) {
+		gog_chart_map_free (chart_map);
 		return;
 	}
 	
-	y_zero = gog_axis_map_get_baseline (y_map);
+	x_map = gog_chart_map_get_axis_map (chart_map, 0);
+	y_map = gog_chart_map_get_axis_map (chart_map, 1);
+	
+	/* Draw drop lines from point to axis start. See comment in
+	 * GogXYPlotView::render */
+
+	gog_axis_map_get_extents (y_map, &drop_lines_y_zero, NULL); 
+	drop_lines_y_zero = gog_axis_map_to_view (y_map, drop_lines_y_zero);
+	y_zero = gog_axis_map_get_baseline (y_map); 
 
 	vals    = g_alloca (num_series * sizeof (double *));
 	error_data = g_alloca (num_series * sizeof (ErrorBarData *));
 	lengths = g_alloca (num_series * sizeof (unsigned));
 	styles  = g_alloca (num_series * sizeof (GogStyle *));
 	path    = g_alloca (num_series * sizeof (ArtVpath *));
-	errors = g_alloca (num_series * sizeof (GogErrorBar *));
+	errors	= g_alloca (num_series * sizeof (GogErrorBar *));
+	lines	= g_alloca (num_series * sizeof (GogSeriesLines *));
+	drop_paths = g_alloca (num_series * sizeof (ArtVpath *));
 
 	i = 0;
 	for (ptr = model->base.series ; ptr != NULL ; ptr = ptr->next) {
@@ -323,6 +339,21 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 			error_data[i] = g_malloc (sizeof (ErrorBarData) * lengths[i]);
 		else
 			error_data[i] = NULL;
+		if (series->has_drop_lines) {
+			if (!role)
+				role = gog_object_find_role_by_name (
+							GOG_OBJECT (series), "Drop lines");
+			lines[i] = GOG_SERIES_LINES (
+					gog_object_get_child_by_role (GOG_OBJECT (series), role));
+			drop_paths [i] = g_malloc (sizeof (ArtVpath) * (num_elements * 2 + 1));
+			for (j = 0; j < num_elements; j++) {
+				drop_paths[i][2 * j].code = ART_MOVETO;
+				drop_paths[i][2 * j + 1].code = ART_LINETO;
+				drop_paths[i][2 * j + 1].y = drop_lines_y_zero; 
+			}
+			drop_paths[i][2 * j].code = ART_END;
+		} else
+			lines[i] = NULL;
 		i++;
 	}
 
@@ -353,7 +384,7 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 			k = 2 * lengths[i] - j + 1;
 
 			if (is_area_plot && (type != GOG_1_5D_NORMAL)) {
-				path[i][k].x = gog_axis_map_to_view (x_map, j - 1);
+				path[i][k].x = gog_axis_map_to_view (x_map, j);
 				path[i][k].code = ART_LINETO;
 
 				if (type == GOG_1_5D_STACKED)
@@ -368,7 +399,7 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 						 y_zero);
 			}
 
-			path[i][j].x = gog_axis_map_to_view (x_map, j - 1);
+			path[i][j].x = gog_axis_map_to_view (x_map, j);
 			if (type == GOG_1_5D_NORMAL && !is_area_plot) 
 				if (gog_axis_map_finite (y_map, vals[i][j-1])) 
 					if (j > 1 && path[i][j-1].code == ART_MOVETO_OPEN)
@@ -383,7 +414,7 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 			sum += value;
 
 			if (gog_error_bar_is_visible (errors[i])) 
-				error_data[i][j-1].x = j - 1;
+				error_data[i][j-1].x = j;
 
 			switch (type) {
 				case GOG_1_5D_NORMAL :
@@ -421,10 +452,16 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 					}
 					break;
 			}
+			if (lines[i]) {
+				drop_paths[i][2 * j - 2].x = drop_paths[i][2 * j - 1].x = path[i][j].x;
+				drop_paths[i][2 * j - 2].y = path[i][j].y;
+			}
+
 		}
 	}
-
-	gog_renderer_clip_push (view->renderer, &view->allocation);
+	
+	gog_renderer_push_clip (view->renderer, 
+				gog_renderer_get_rectangle_vpath (&view->allocation));
 
 	for (i = 0; i < num_series; i++) {
 
@@ -440,8 +477,7 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 		if (!is_area_plot) {
 			path[i][lengths[i] +1].code = ART_END;
 
-			gog_renderer_draw_path (view->renderer,
-				path[i], NULL);
+			gog_renderer_draw_path (view->renderer, path[i]);
 		} else {
 			switch (type) {
 				case GOG_1_5D_NORMAL :
@@ -469,13 +505,22 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 				path[i][j+1].code = ART_END;
 				break;
 			}
-			gog_renderer_draw_polygon (view->renderer,
-							 path[i], FALSE, NULL);
+			gog_renderer_draw_polygon (view->renderer, path[i], FALSE);
 		}
 
 		gog_renderer_pop_style (view->renderer);
 	}
 
+	/*Now draw drop lines */
+	for (i = 0; i < num_series; i++)
+		if (lines[i] != NULL) {
+			gog_renderer_push_style (view->renderer,
+				gog_styled_object_get_style (GOG_STYLED_OBJECT (lines[i])));
+			gog_series_lines_render (lines[i], view->renderer, bbox, drop_paths[i], FALSE);
+			gog_renderer_pop_style (view->renderer);
+			g_free (drop_paths[i]);
+		}
+
 	/*Now draw error bars */
 	for (i = 0; i < num_series; i++)
 		if (gog_error_bar_is_visible (errors[i]))
@@ -485,7 +530,7 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 						      error_data[i][j].minus, error_data[i][j].plus, 
 						      FALSE);
 
-	gog_renderer_clip_pop (view->renderer);
+	gog_renderer_pop_clip (view->renderer);
 
 	/*Now draw markers*/
 	if (!is_area_plot) { 
@@ -521,8 +566,7 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 		g_free (error_data[i]);
 	}
 
-	gog_axis_map_free (x_map);
-	gog_axis_map_free (y_map);
+	gog_chart_map_free (chart_map);
 }
 
 static gboolean
