@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -300,24 +300,6 @@ gog_contour_plot_update (GogObject *obj)
 		plot_contour_parent_klass->update (obj);
 }
 
-static GogAxisSet
-gog_contour_plot_axis_set_pref (GogPlot const *plot)
-{
-	return GOG_AXIS_SET_XY_pseudo_3d;
-}
-
-static gboolean
-gog_contour_plot_axis_set_is_valid (GogPlot const *plot, GogAxisSet type)
-{
-	return type == GOG_AXIS_SET_XY_pseudo_3d;
-}
-
-static gboolean
-gog_contour_plot_axis_set_assign (GogPlot *plot, GogAxisSet type)
-{
-	return type == GOG_AXIS_SET_XY_pseudo_3d;
-}
-
 static GOData *
 gog_contour_plot_axis_get_bounds (GogPlot *plot, GogAxisType axis, 
 				  GogPlotBoundInfo * bounds)
@@ -512,9 +494,7 @@ gog_contour_plot_class_init (GogContourPlotClass *klass)
 	gog_plot_klass->desc.num_series_min = 1;
 	gog_plot_klass->desc.num_series_max = 1;
 	gog_plot_klass->series_type = gog_surface_series_get_type();
-	gog_plot_klass->axis_set_pref = gog_contour_plot_axis_set_pref;
-	gog_plot_klass->axis_set_is_valid = gog_contour_plot_axis_set_is_valid;
-	gog_plot_klass->axis_set_assign = gog_contour_plot_axis_set_assign;
+	gog_plot_klass->axis_set = GOG_AXIS_SET_XY_pseudo_3d;
 	gog_plot_klass->axis_get_bounds	= gog_contour_plot_axis_get_bounds;
 	gog_plot_klass->foreach_elem = gog_contour_plot_foreach_elem;
 	gog_plot_klass->update_3d = gog_contour_plot_update_3d;
@@ -636,7 +616,8 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 	g_object_unref (style);
 
 	/* clip to avoid problems with logarithmic axes */
-	gog_renderer_clip_push (rend, &(view->residual));
+	gog_renderer_push_clip (rend, 
+				gog_renderer_get_rectangle_vpath (&view->residual));
 
 	style = gog_style_new ();
 	style->interesting_fields = GOG_STYLE_FILL | GOG_STYLE_OUTLINE;
@@ -783,7 +764,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 				path[k].y = y[0];
 				path[k + 1].code = ART_END;
 				/* narrow parameter is TRUE below to avoid border effects */
-				gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+				gog_renderer_draw_polygon (rend, path, FALSE);
 				gog_renderer_pop_style (rend);
 			} else {
 				kmax = 3 - nans;
@@ -843,7 +824,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 						xl[0] = lines[l].x = path[2].x = x[0] + t * (x[1] - x[0]);
 						yl[0] = lines[l++].y = path[2].y = y[0] + t * (y[1] - y[0]);
 						gog_renderer_push_style (rend, style);
-						gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+						gog_renderer_draw_polygon (rend, path, FALSE);
 						gog_renderer_pop_style (rend);
 						path[4].code = ART_LINETO;
 						path[5].code = ART_END;
@@ -866,7 +847,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							xl[0] = lines[l].x = path[2].x = x[0] + t * (x[1] - x[0]);
 							yl[0] = lines[l++].y = path[2].y = y[0] + t * (y[1] - y[0]);
 							gog_renderer_push_style (rend, style);
-							gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+							gog_renderer_draw_polygon (rend, path, FALSE);
 							gog_renderer_pop_style (rend);
 						}
 					} else
@@ -894,7 +875,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 						xl[4] = lines[l].x = path[2].x = x[2] + t * (x[3] - x[2]);
 						yl[4] = lines[l++].y = path[2].y = y[2] + t * (y[3] - y[2]);
 						gog_renderer_push_style (rend, style);
-						gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+						gog_renderer_draw_polygon (rend, path, FALSE);
 						gog_renderer_pop_style (rend);
 						path[4].code = ART_LINETO;
 						path[5].code = ART_END;
@@ -917,7 +898,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							xl[4] = lines[l].x = path[2].x = x[2] + t * (x[3] - x[2]);
 							yl[4] = lines[l++].y = path[2].y = y[2] + t * (y[3] - y[2]);
 							gog_renderer_push_style (rend, style);
-							gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+							gog_renderer_draw_polygon (rend, path, FALSE);
 							gog_renderer_pop_style (rend);
 						}
 					} else
@@ -947,7 +928,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 						style->outline.color = color[k];
 						style->fill.pattern.back = color[k];
 						gog_renderer_push_style (rend, style);
-						gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+						gog_renderer_draw_polygon (rend, path, FALSE);
 						gog_renderer_pop_style (rend);
 						path[4].code = ART_LINETO;
 						path[5].code = ART_END;
@@ -970,7 +951,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							style->outline.color = color[k];
 							style->fill.pattern.back = color[k];
 							gog_renderer_push_style (rend, style);
-							gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+							gog_renderer_draw_polygon (rend, path, FALSE);
 							gog_renderer_pop_style (rend);
 							k--;
 						}
@@ -1000,7 +981,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 						style->outline.color = color[k];
 						style->fill.pattern.back = color[k];
 						gog_renderer_push_style (rend, style);
-						gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+						gog_renderer_draw_polygon (rend, path, FALSE);
 						gog_renderer_pop_style (rend);
 						path[4].code = ART_LINETO;
 						path[5].code = ART_END;
@@ -1023,7 +1004,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							style->outline.color = color[k];
 							style->fill.pattern.back = color[k];
 							gog_renderer_push_style (rend, style);
-							gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+							gog_renderer_draw_polygon (rend, path, FALSE);
 							gog_renderer_pop_style (rend);
 							k--;
 						}
@@ -1087,7 +1068,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							style->outline.color = color[zn];
 							style->fill.pattern.back = color[zn];
 							gog_renderer_push_style (rend, style);
-							gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+							gog_renderer_draw_polygon (rend, path, FALSE);
 							if (xl[2] < 0.) {
 								path[4].x = path[0].x = x[2];
 								path[4].y = path[0].y = y[2];
@@ -1104,7 +1085,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							path[1].y = yb[1];
 							path[3].x = xb[2];
 							path[3].y = yb[2];
-							gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+							gog_renderer_draw_polygon (rend, path, FALSE);
 							gog_renderer_pop_style (rend);
 							if (xl[2] < 0.) {
 								path[4].x = path[0].x = x[1];
@@ -1125,7 +1106,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							style->outline.color = color[zx];
 							style->fill.pattern.back = color[zx];
 							gog_renderer_push_style (rend, style);
-							gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+							gog_renderer_draw_polygon (rend, path, FALSE);
 							if (xl[6] < 0.) {
 								path[4].x = path[0].x = x[3];
 								path[4].y = path[0].y = y[3];
@@ -1142,7 +1123,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							path[1].y = yb[2];
 							path[3].x = xb[3];
 							path[3].y = yb[3];
-							gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+							gog_renderer_draw_polygon (rend, path, FALSE);
 							gog_renderer_pop_style (rend);
 						} else {
 							if (up) {
@@ -1177,7 +1158,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 								style->outline.color = color[zx];
 								style->fill.pattern.back = color[zx];
 								gog_renderer_push_style (rend, style);
-								gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+								gog_renderer_draw_polygon (rend, path, FALSE);
 								if (xl[5] < 0.) {
 									path[4].code = ART_END;
 									path[0].x = path[3].x = x[3];
@@ -1200,7 +1181,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 								t = (zx - zval[3]) / (zval[0] - zval[3]);
 								xl[6] = lines[l].x = path[2].x = x[3] + t * (x[0] - x[3]);
 								yl[6] = lines[l++].y = path[2].y = y[3] + t * (y[0] - y[3]);
-								gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+								gog_renderer_draw_polygon (rend, path, FALSE);
 								gog_renderer_pop_style (rend);
 							} else {
 								/* saddle point is in the upper slice */
@@ -1233,7 +1214,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 								style->outline.color = color[zn];
 								style->fill.pattern.back = color[zn];
 								gog_renderer_push_style (rend, style);
-								gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+								gog_renderer_draw_polygon (rend, path, FALSE);
 								if (xl[4] < 0.) {
 									path[4].code = ART_END;
 									path[0].x = path[3].x = x[2];
@@ -1254,7 +1235,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 								t = (k - zval[2]) / (zval[3] - zval[2]);
 								xl[4] = lines[l].x = path[2].x = x[2] + t * (x[3] - x[2]);
 								yl[4] = lines[l++].y = path[2].y = y[2] + t * (y[3] - y[2]);
-								gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+								gog_renderer_draw_polygon (rend, path, FALSE);
 								gog_renderer_pop_style (rend);
 								zn = zx;
 							}
@@ -1282,7 +1263,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							style->outline.color = color[zn];
 							style->fill.pattern.back = color[zn];
 							gog_renderer_push_style (rend, style);
-							gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+							gog_renderer_draw_polygon (rend, path, FALSE);
 							gog_renderer_pop_style (rend);
 						}
 					} else {
@@ -1309,7 +1290,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 						style->outline.color = color[zx];
 						style->fill.pattern.back = color[zx];
 						gog_renderer_push_style (rend, style);
-						gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+						gog_renderer_draw_polygon (rend, path, FALSE);
 						gog_renderer_pop_style (rend);
 					}
 				} else {
@@ -1392,7 +1373,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							path[p-1].y = path[0].y;
 						}
 						path[p].code = ART_END;
-						gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+						gog_renderer_draw_polygon (rend, path, FALSE);
 						gog_renderer_pop_style (rend);
 						path[0].x = lines[l - 1].x;
 						path[0].y = lines[l - 1].y;
@@ -1417,7 +1398,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 					style->outline.color = color[zmin];
 					style->fill.pattern.back = color[zmin];
 					gog_renderer_push_style (rend, style);
-					gog_renderer_draw_polygon (rend, path, FALSE, NULL);
+					gog_renderer_draw_polygon (rend, path, FALSE);
 					gog_renderer_pop_style (rend);
 				}
 			}
@@ -1425,9 +1406,9 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 	}
 	lines[l].code = ART_END;
 	gog_renderer_push_style (rend, GOG_STYLED_OBJECT (series)->style);
-	gog_renderer_draw_path  (rend, lines, NULL);
+	gog_renderer_draw_path  (rend, lines);
 	gog_renderer_pop_style (rend);
-	gog_renderer_clip_pop (rend);
+	gog_renderer_pop_clip (rend);
 	art_free (lines);
 	art_free (path);
 	g_object_unref (style);
